@@ -570,89 +570,6 @@ rev.Splits <- function(x) {
   x
 }
 
-#' Split matching
-#'
-#' `match()` returns a vector of the positions of (first) matches of splits in
-#' its first argument in its second.
-#' `%in%` is a more intuitive interface as a binary operator, which returns
-#' a logical vector indicating whether there is a match or not for each
-#' split in its left operand.
-#'
-#' `in.Splits()` is an alias for `%in%`, included for backwards compatibility.
-#' It is deprecated and will be removed in a future release.
-#'
-#' @param x,table Object of class `Splits`.
-#' @param nomatch Integer value that will be used in place of `NA` in the case
-#' where no match is found.
-#' @param incomparables Ignored. (Included for consistency with generic.)
-# @param incomparables A vector of values that cannot be matched. Any value in
-# `x` matching a value in this vector is assigned the `nomatch` value.
-# For historical reasons, `FALSE` is equivalent to `NULL`.
-#'
-#' @return `match()` returns an integer vector specifying the position in
-#' `table` that matches each element in `x`, or `nomatch` if no match is found.
-#'
-#' @examples
-#' splits1 <- as.Splits(BalancedTree(7))
-#' splits2 <- as.Splits(PectinateTree(7))
-#'
-#' match(splits1, splits2)
-# Turns base functions into S3 generics that can handle `Splits` objects
-# (as well as `integer64`s).  This follows equivalent functions in the
-# "\pkg{bit64}" package.
-#
-#' @seealso Corresponding base functions are documented in
-#' [`match()`][base::match].
-#'
-#' @aliases match,Splits,Splits-method
-#' @family Splits operations
-#' @keywords methods
-#' 
-#' @name match.Splits
-#' @export
-setMethod("match",
-          signature(x = "Splits", table = "Splits"),
-          function(x, table, nomatch, incomparables) {
-            if(missing("nomatch")) {
-              nomatch <- NA_integer_
-            }
-            nomatch <- as.integer(nomatch)
-            if (length(nomatch) != 1L) {
-              nomatch <- NA_integer_
-            }
-            vapply(seq_along(x), function(i) {
-              ret <- which(table %in% x[[i]])
-              if (length(ret) == 0) ret <- nomatch
-              ret
-            }, integer(1))
-})
-
-# Replaces a previous approach (TreeTools <= 1.6.0) that followed
-# https://github.com/cran/bit64/blob/master/R/patch64.R
-
-
-#' @rdname match.Splits
-in.Splits <- function(x, table) {
-  .Deprecated("%in%")
-  .in.Splits(x, table)
-}
-
-.in.Splits <- function(x, table) {
-  duplicated(c(x, table), fromLast = TRUE)[seq_along(x)]
-}
-
-#' @rdname match.Splits
-setGeneric("match")
-
-
-#' @rdname match.Splits
-#' @export
-#' @keywords methods
-setMethod("%in%",
-          signature(x = "Splits", table = "Splits"),
-          .in.Splits)
-
-
 #' Polarize splits on a single taxon
 #'
 #' @param x Object of class [`Splits`].
